#!/bin/sh
# Bryant Hansen

ME="$(basename "$0")"
USAGE="$ME"

DebugMessage() {
    local LOG_RECORD_HEADER="`date "+%Y%m%d_%H%M%S"` (${ME}):"
    echo "${LOG_RECORD_HEADER} $*" >&2
}

# source config info
CONF_FILE="/etc/logfile_uploader.conf"
if [[ ! -f "$CONF_FILE" ]] ; then
    DebugMessage "ERROR: configuration file $CONF_FILE not found."
    DebugMessage "Exiting abnormally."
    exit 2
fi
. "$CONF_FILE"

mac=$(get_mac_address.sh)
if [[ ! "$mac" ]] ; then
	DebugMessage "ERROR: failed to retrieve mac address of localhost."
	DebugMessage "  Exiting abnormally."
	exit 4
fi
USER=$mac
if [[ ! "${USER%%[0-9]*}" ]] ; then
    echo "$ME WARNING: MAC address does not begin with a letter.  Modifying registration name from $USER to m_${USER}" >&2
    USER="m_${USER}"
fi

KEYFILE=/home/root/.ssh/${USER}.key
DEST_DIR=/var/log/digitalSTROM/${USER}

# verify that the key file exists
if [[ ! -f "$KEYFILE" ]] ; then
    DebugMessage "ERROR: no access to account on server"
    DebugMessage "verify installation failure"
    exit 5
fi

if [[ ! -d "$SYNC_SRC_DIR" ]] ; then
    DebugMessage "ERROR: backup source $SYNC_SRC_DIR does not exist."
	DebugMessage "  Exiting abnormally."
    exit 6
fi

[[ ! "$TIMEOUT_SECONDS" ]] && TIMEOUT_SECONDS=60
echo "rsync --archive                                      \
            --verbose                                      \
            --update                                       \
            --copy-links                                   \
            --compress                                     \
            --timeout=${TIMEOUT_SECONDS}                   \
            $RSYNC_OPTS                                    \
            --rsh='ssh $SSH_OPTS -i $KEYFILE'              \
            ${SYNC_SRC_DIR}/                               \
            ${USER}@${SERVER}:${DEST_DIR}/"
